PieRTCOptions class

Options for a PieRTC room, set via PieSocket.join's named params.

Constructors

PieRTCOptions({bool shouldBroadcast = true, bool video = false, bool audio = true, String cameraFacing = 'user', void onLocalVideo(MediaStream stream, PieRTC pieRTC)?, void onParticipantJoined(String uuid, MediaStream stream)?, void onParticipantLeft(String uuid)?, void onScreenSharingStopped(String uuid, String streamId)?})

Properties

audio ↔ bool
getter/setter pair
cameraFacing ↔ String
Which camera to open for a video room: 'user' (front — the default, what a 1:1 call wants) or 'environment' (rear). Flip it at runtime with PieRTC.switchCamera.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onLocalVideo ↔ void Function(MediaStream stream, PieRTC pieRTC)?
getter/setter pair
onParticipantJoined ↔ void Function(String uuid, MediaStream stream)?
getter/setter pair
onParticipantLeft ↔ void Function(String uuid)?
getter/setter pair
onScreenSharingStopped ↔ void Function(String uuid, String streamId)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldBroadcast ↔ bool
getter/setter pair
video ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited