PieSocketOptions class

Constructors

PieSocketOptions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApiKey() → String
getAuthEndpoint() → String
getAuthHeaders() → Map<String, String>
getClusterDomain() → String
getClusterId() → String
getEnableLogs() → bool
getForceAuth() → bool
getJwt() → String
getNotifySelf() → int
getPresence() → int
getSsl() → bool
getUserId() → String
getVersion() → String
getWebSocketEndpoint() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApiKey(String apiKey) → void
setAuthEndpoint(String authEndpoint) → void
setAuthHeaders(Map<String, String> authHeaders) → void
setClusterDomain(String clusterDomain) → void
setClusterId(String clusterId) → void
setEnableLogs(bool enableLogs) → void
setForceAuth(bool forceAuth) → void
setJwt(String jwt) → void
setNotifySelf(bool notifySelf) → void
setPresence(bool presence) → void
setSsl(bool ssl) → void
setUserId(String userId) → void
setVersion(String version) → void
setWebSocketEndpoint(String webSocketEndpoint) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited